@@ -124,7 +124,7 @@ def main():
     logfile = os.path.join(logdir, "log.txt")
     logging.basicConfig(filename=logfile, filemode="w")
 
-    from tff import tff
+    from tffstub import tff
     import input
     import output
     import controller
